/* myClass.pde

Written by: Marvin C. Jones and Richard (Rick) G. Freedman

Goes with program: Ellipse_12.pde

We rewrite Ellipse_8.pde so that all the programming for the circle is handled 
by a class instead of inside the draw() function itself.  This has many other 
benefits which we will see later because a class is a blueprint for creating 
objects.  However, we first organize the code a little more by using functions.
We already saw some examples such as setup(), draw(), and the constructor for 
myClass.  Now we will create a few more to make it easier to understand all the 
code in drawMyself() - compare this with the myClass.pde that goes with Ellipse_9.pde.  This is the same from myClass.pde which goes with Ellipse_10.pde and 
Ellipse_11.pde, but Ellipse_12.pde is different.
*/

//We give the class a name since we can have more than one thing to create
class myClass
{
  //The class uses these variables for itself (they are not from Ellipse_9.pde)
  //The variables called x and y each store an integer (int)
  int x;
  int y;
  //The variable named radius also stores an integer (int)
  int radius;

  //The variable named arrayList stores a list (called an array []) of integers (int)
  int[] arrayList;
  //We will use a variable called counter to count which item in the list we will 
  //  use for the next movement in the animation
  int counter;

  //This is called a constructor function because it starts with 'public [class's name](...)
  //  We use this to explain how to create an object using the blueprints for myClass
  //  (Compare it to setup() in Ellipse_8.pde and Ellipse_9.pde)
  //NOTE: The variables in parentheses are set (=) by the values when 'new' is 
  //      used (see Ellipse_9.pde)
  public myClass(int x_t, int y_t, int radius_t)
  {
    //The equals sign (=) tells the program to store a value in a variable
    //  We will store the information used to create the object in the class's
    //  variables (the ones in parentheses are only temporary)
    x = x_t;
    y = y_t;
    radius = radius_t;
    //We will begin the counter at the first item in the array
    counter = 0;

    //The array needs to know how many numbers are in its list - let's use 5
    arrayList = new int[5];

    //Now we can store a value at each item in this list
    //  Notice that the brackets are now on the side with the name of the array
    //NOTE: We begin counting items in an array at 0 instead of 1
    arrayList[0] = -10;
    arrayList[1] = 40;
    arrayList[2] = -50;
    arrayList[3] = 20;
    arrayList[4] = 80; 
  }

  //We will use this function as a command we create to do the drawing for our 
  //  circle (compare it to draw() in Ellipse_8.pde and Ellipse_9.pde)
  public void drawMyself()
  {
    //We will draw a circle at the location according to the values stored by our 
    //  variables (we set x and y in the constructor, but now we change them at 
    //  the end of drawMyself())
    ellipse(x, y, radius, radius);

    //We create these functions below - compare them to what was written here 
    //  in myClass.pde which goes with Ellipse_9.pde
    updateLocation();
    checkBoundaries();
  }

  //This function runs the commands to change the circle's position
  public void updateLocation()
  {
    //Use the counter-th value in the list to change the values of x and y
    //  This will change the circle's position when drawMyself() is performed next time
    x = x + arrayList[counter];
    y = y + arrayList[counter];

    //Move to the next item in the list (we combine the two steps from Ellipse_7.pde)
    counter = (counter + 1) % 5;
  }

  //This function runs the commands to keep the circle's position inside the window
  public void checkBoundaries()
  {
    //If the current value of x (after the change) is less than 0, then the center 
    //  of the circle will appear to the left of the left-edge of the window
    //  (moving in the direction outside the window)
    if(x < 0)
    {
      //So we will place the center of the circle on the left-edge of the window 
      //  to keep it inside the drawing region
      x = 0;
    }
    //If the current value of x (after the change) is not less than 0, then we 
    //  check whether it is greater than 500 which would place the center of the 
    //  circle to the right of the right-edge of the window (also moving outside)
    else if(x > 500)
    {
      //In this case, we will place the center of the circle on the right edge of 
      //  the window to keep it inside the drawing region
      x = 500;
    }

    //If the current value of y (after the change) is not less than 0, then the 
    //  center of the circle will appear above the top-edge of the window (moving 
    //  in the direction outside the window)
    if(y < 0)
    {
      //So we will place the center of the circle on the to-edge of the window to 
      //  keep it inside the drawing region
      y = 0;
    }
    //If the current value of y (after the change) is not less than 0, then we 
    //  check whether it is greater than 300 which would place the center of the 
    //  circle below the bottom-edge of the window (also moving outside)
    else if(y > 300)
    {
      //In this case, we will place the center of the circle on the bottom-edge 
      //  of the window to keep it inside the drawing region
      y = 300;
    }
  }
}
